import os

PROVIDER = os.environ.get('CLOUD_SERVICES_PROVIDER')
REGION = os.environ.get('CLOUD_SERVICES_REGION')

# Notification Bus services
NOTIFICATION = 'Notification'
SUSCRIPTION = 'Subscription'
